==> apache-iotdb-2.0.2-1-source-release.zip: apache-iotdb-2.0.2-1/iotdb-core/confignode/src/main/java/org/apache/iotdb/confignode/consensus/request/write/table/AddTableColumnPlan.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.confignode.consensus.request.write.table;

import org.apache.iotdb.commons.schema.table.column.TsTableColumnSchema;
import org.apache.iotdb.commons.schema.table.column.TsTableColumnSchemaUtil;
import org.apache.iotdb.confignode.consensus.request.ConfigPhysicalPlanType;

import org.apache.tsfile.utils.ReadWriteIOUtils;

import java.io.DataOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.List;

public class AddTableColumnPlan extends AbstractTablePlan {

  private List<TsTableColumnSchema> columnSchemaList;

  private boolean isRollback;

  public AddTableColumnPlan() {
    super(ConfigPhysicalPlanType.AddTableColumn);
  }

  public AddTableColumnPlan(
      final String database,
      final String tableName,
      final List<TsTableColumnSchema> columnSchemaList,
      final boolean isRollback) {
    super(ConfigPhysicalPlanType.AddTableColumn, database, tableName);
    this.columnSchemaList = columnSchemaList;
    this.isRollback = isRollback;
  }

  public List<TsTableColumnSchema> getColumnSchemaList() {
    return columnSchemaList;
  }

  public boolean isRollback() {
    return isRollback;
  }

  @Override
  protected void serializeImpl(final DataOutputStream stream) throws IOException {
    super.serializeImpl(stream);
    TsTableColumnSchemaUtil.serialize(columnSchemaList, stream);
    ReadWriteIOUtils.write(isRollback, stream);
  }

  @Override
  protected void deserializeImpl(final ByteBuffer buffer) throws IOException {
    super.deserializeImpl(buffer);
    this.columnSchemaList = TsTableColumnSchemaUtil.deserializeColumnSchemaList(buffer);
    this.isRollback = ReadWriteIOUtils.readBool(buffer);
  }
}

==> apache-iotdb-2.0.5-source-release.zip: apache-iotdb-2.0.5/iotdb-core/confignode/src/main/java/org/apache/iotdb/confignode/consensus/request/write/table/AddTableColumnPlan.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.confignode.consensus.request.write.table;

import org.apache.iotdb.commons.schema.table.column.TsTableColumnSchema;
import org.apache.iotdb.commons.schema.table.column.TsTableColumnSchemaUtil;
import org.apache.iotdb.confignode.consensus.request.ConfigPhysicalPlanType;

import org.apache.tsfile.utils.ReadWriteIOUtils;

import java.io.DataOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.List;

public class AddTableColumnPlan extends AbstractTablePlan {

  private List<TsTableColumnSchema> columnSchemaList;

  private boolean isRollback;

  public AddTableColumnPlan(final ConfigPhysicalPlanType type) {
    super(type);
  }

  public AddTableColumnPlan(
      final String database,
      final String tableName,
      final List<TsTableColumnSchema> columnSchemaList,
      final boolean isRollback) {
    this(ConfigPhysicalPlanType.AddTableColumn, database, tableName, columnSchemaList, isRollback);
  }

  protected AddTableColumnPlan(
      final ConfigPhysicalPlanType type,
      final String database,
      final String tableName,
      final List<TsTableColumnSchema> columnSchemaList,
      final boolean isRollback) {
    super(type, database, tableName);
    this.columnSchemaList = columnSchemaList;
    this.isRollback = isRollback;
  }

  public List<TsTableColumnSchema> getColumnSchemaList() {
    return columnSchemaList;
  }

  public boolean isRollback() {
    return isRollback;
  }

  @Override
  protected void serializeImpl(final DataOutputStream stream) throws IOException {
    super.serializeImpl(stream);
    TsTableColumnSchemaUtil.serialize(columnSchemaList, stream);
    ReadWriteIOUtils.write(isRollback, stream);
  }

  @Override
  protected void deserializeImpl(final ByteBuffer buffer) throws IOException {
    super.deserializeImpl(buffer);
    this.columnSchemaList = TsTableColumnSchemaUtil.deserializeColumnSchemaList(buffer);
    this.isRollback = ReadWriteIOUtils.readBool(buffer);
  }
}
